ExceptionInfo class

Information about an exception encountered by Lavalink.

Annotations
  • @JsonSerializable.new()

Constructors

ExceptionInfo({required String? message, required String severity, required String cause, required String causeStackTrace})
Create a new ExceptionInfo.
ExceptionInfo.fromJson(Map<String, Object?> json)
factory

Properties

cause → String
The cause of the exception.
final
causeStackTrace → String
The full stack trace of the cause.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
A message describing the exception.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → String
The severity of the exception.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited