LavalinkExternalPlugin class abstract
An abstract class representing a plugin. A plugin can handle multiple events and provide additional functionality to the LavalinkClient.
You might also be interested in:
- LavalinkExternalPluginEventHandler which represents a handler for an external plugin event.
- LavalinkClient which represents a client connected to a lavalink server.
Properties
- client → LavalinkClient
-
A reference to this client.
final
-
handledEvents
→ Map<
String, LavalinkExternalPluginEventHandler> -
A list of all handled events by this plugins.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of this plugin.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited